@@ -1,5 +1,5 @@
 package CPAN::Mini;
-our $VERSION = '0.40';
+our $VERSION = '0.500';
 
 use strict;
 use warnings;
@@ -10,9 +10,9 @@ CPAN::Mini - create a minimal mirror of CPAN
 
 =head1 VERSION
 
-version 0.40
+version 0.500
 
- $Id: /my/rjbs/code/minicpan/trunk/lib/CPAN/Mini.pm 15995 2005-11-04T12:20:23.253990Z rjbs  $
+ $Id: /my/cs/projects/minicpan/trunk/lib/CPAN/Mini.pm 3924 2005-11-05T01:48:37.834491Z rjbs  $
 
 =head1 SYNOPSIS
 
@@ -217,11 +217,13 @@ This method updates the index files from the CPAN.
 sub mirror_indices {
 	my $self = shift;
 
-	$self->mirror_file($_) for qw(
-	                              authors/01mailrc.txt.gz
-	                              modules/02packages.details.txt.gz
-	                              modules/03modlist.data.gz
-	                             );
+  my @fixed_mirrors = qw(
+	    authors/01mailrc.txt.gz
+	    modules/02packages.details.txt.gz
+	    modules/03modlist.data.gz
+    );
+
+	$self->mirror_file($_) for @fixed_mirrors, @{$self->{also_mirror}};
 }
 
 =head2 C<< mirror_file($path, $skip_if_present) >>
